@@ -96,7 +96,7 @@ sub get_download_infos {
                         next VIDEO;
                     }
                     elsif ( $choice eq $pref_qualities ) {
-                        _set_preferred_qualities( $opt, $info, $ex, $video_id );
+                        set_preferred_qualities( $opt, $info, $ex, $video_id );
                         print up( $opt->{up} ), cldown;
                         $opt->{up} = 0;
                         next MENU;
