@@ -6,7 +6,7 @@ use strict;
 use 5.010000;
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( read_config_file set_options sort_order_list );
+our @EXPORT_OK = qw( read_config_file set_options );
 
 use File::Spec::Functions qw( catfile );
 use File::Temp            qw();
@@ -22,7 +22,8 @@ use Term::ReadLine::Simple qw();
 use Text::LineFold         qw();
 use Try::Tiny              qw( try catch );
 
-use App::YTDL::Helper qw( encode_fs write_json read_json HIDE_CURSOR SHOW_CURSOR );
+use App::YTDL::Helper        qw( encode_fs write_json read_json HIDE_CURSOR SHOW_CURSOR );
+use App::YTDL::Choose_Videos qw( set_sort_videolist );
 
 
 
@@ -90,7 +91,7 @@ sub _menus {
             [ 'group_download',  "- Download"   ],
             [ 'group_merge',     "- Merge"      ],
             [ 'group_history',   "- History"    ],
-            [ 'group_list_menu', "- Video list menu" ],
+            [ 'group_list_menu', "- Video List" ],
             [ 'group_output',    "- Appearance" ],
             [ 'list_extractors', "  Extractors" ],
         ],
@@ -251,8 +252,8 @@ sub set_options {
             elsif ( $choice eq "overwrite" ) {
                 my $prompt = 'Overwrite files';
                 my $list = [
-                    'Append if incomplete',
-                    'Overwrite'
+                    'NO (append)',
+                    'YES'
                 ];
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
@@ -386,7 +387,7 @@ sub set_options {
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
             elsif ( $choice eq "list_sort_item" ) {
-                sort_order_list( $opt );
+                set_sort_videolist( $opt );
             }
             elsif ( $choice eq "show_view_count" ) {
                 my $prompt = 'Show the view count in channel/playlist menus';
@@ -516,59 +517,6 @@ sub _opt_choose_from_list_value {
 }
 
 
-sub sort_order_list {
-    my ( $opt ) = @_;
-    my $backup_item  = $opt->{list_sort_item};
-    my $backup_order = $opt->{list_sort_order};
-    my $sort_items = [ 'upload_date', 'title', 'view_count_raw', 'duration' ];
-    my $confirm = '  CONFIRM';
-    my @pre = ( undef, $confirm );
-    my $choices = [ @pre, map { s/_raw\z//; s/_/ /g; '- ' . ucfirst } @$sort_items ];
-
-    while ( 1 ) {
-        my $current = ucfirst $opt->{list_sort_item};
-        $current =~ s/_raw\z//;
-        $current =~ s/_/ /g;
-        my $prompt = sprintf 'Sort item: [%s]', $current;
-        my $idx = choose (
-            $choices,
-            { prompt => $prompt, clear_screen => 0, layout => 3, index => 1, undef => '  BACK' }
-        );
-        if ( ! defined $idx || ! defined $choices->[$idx] ) {
-            $opt->{list_sort_item} = $backup_item;
-            return;
-        }
-        if ( $choices->[$idx] eq $confirm ) {
-            $opt->{change}++;
-            last;
-        }
-        $idx -= @pre;
-        $opt->{list_sort_item} = $sort_items->[$idx];
-    }
-
-    while ( 1 ) {
-        my $curr_sort_item = ucfirst $opt->{list_sort_item};
-        $curr_sort_item =~ s/_raw\z//;
-        $curr_sort_item =~ s/_/ /g;
-        my $order_prompt = sprintf 'Sort order "%s": [%s]', $curr_sort_item, $opt->{list_sort_order};
-        my $choice = choose (
-            [ @pre, '- Asc', '- Desc' ],
-            { prompt => $order_prompt, clear_screen => 0, layout => 3, undef => '  BACK' }
-        );
-        if ( ! defined $choice ) {
-            $opt->{list_sort_order} = $backup_order;
-            return;
-        }
-        if ( $choice eq $confirm ) {
-            $opt->{change}++;
-            return;
-        }
-        $choice =~ s/^-\s//;
-        $opt->{list_sort_order} = $choice;
-    }
-}
-
-
 sub _write_config_file {
     my ( $opt, $file, @keys ) = @_;
     if ( ! $opt->{change} ) {
